Stan Math Library: Member List

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

stan::math::var Member List

This is the complete list of members for stan::math::var, including all inherited members.

adj() const | stan::math::var | inline
grad(std::vector< var > &x, std::vector< double > &g) | stan::math::var | inline
grad() | stan::math::var | inline
is_uninitialized() | stan::math::var | inline
operator*() | stan::math::var | inline
operator*=(const var &b) | stan::math::var | inline
operator*=(const double b) | stan::math::var | inline
operator+=(const var &b) | stan::math::var | inline
operator+=(const double b) | stan::math::var | inline
operator-=(const var &b) | stan::math::var | inline
operator-=(const double b) | stan::math::var | inline
operator->() | stan::math::var | inline
operator/=(const var &b) | stan::math::var | inline
operator/=(const double b) | stan::math::var | inline
operator<<(std::ostream &os, const var &v) | stan::math::var | friend
Scalar typedef | stan::math::var |
val() const | stan::math::var | inline
var() | stan::math::var | inline
var(vari *vi) | stan::math::var | inline
var(float x) | stan::math::var | inline
var(double x) | stan::math::var | inline
var(long double x) | stan::math::var | inline
var(bool x) | stan::math::var | inline
var(char x) | stan::math::var | inline
var(short x) | stan::math::var | inline
var(int x) | stan::math::var | inline
var(long x) | stan::math::var | inline
var(unsigned char x) | stan::math::var | inline
var(unsigned short x) | stan::math::var | inline
var(unsigned int x) | stan::math::var | inline
var(unsigned long x) | stan::math::var | inline
vi_ | stan::math::var |

[ Stan Home Page ] © 2011–2016, Stan Development Team.